@@ -4,13 +4,10 @@ use warnings;
 use Dancer qw(:script);
 use WWW::Hashbang::Pastebin;
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.004'; # VERSION
 # PODNAME: app.pl
 # ABSTRACT: runner for WWW::Hashbang::Pastebin
 
-WWW::Hashbang::Pastebin::schema->deploy
-    unless $ENV{PLACK_ENV};
-
 dance;
 
 __END__
@@ -24,7 +21,7 @@ app.pl - runner for WWW::Hashbang::Pastebin
 
 =head1 VERSION
 
-version 0.002
+version 0.004
 
 =head1 AVAILABILITY
 
