@@ -10,12 +10,12 @@ use Try::Tiny;
 use DateTime;
 
 # ABSTRACT: command line pastebin
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 
 my $mapper = do {
     my $key = config->{key} || join '', ('a'..'z', 0..9);
-    $key =~ tr/.//d;
+    $key =~ tr/+//d;
     Integer::Tiny->new($key);
 };
 
@@ -51,7 +51,7 @@ post '/' => sub {
 
 get '/:id' => sub {
     my $ext_id = param('id');
-    my $line_nos = ($ext_id =~ s{\.$}{});
+    my $line_nos = ($ext_id =~ s{\+$}{});
 
     my $int_id = try { $mapper->decrypt( $ext_id ) } || do {
         status 'bad_request';
@@ -76,7 +76,11 @@ get '/:id' => sub {
 
     headers 'X-Pastebin-ID' => $ext_id;
     if ($line_nos) {
-        return template paste => { content => $paste->content };
+        open my $in, '<', \$paste->content;
+        1 while (<$in>);
+        my $lines = $.;
+        close $in;
+        return template paste => { content => $paste->content, lines => [1..$lines] };
     }
     else {
         content_type('text/plain');
@@ -98,13 +102,13 @@ WWW::Hashbang::Pastebin - command line pastebin
 
 =head1 VERSION
 
-version 0.002
+version 0.004
 
 =head1 SYNOPSIS
 
     $ (hostname ; uptime) | curl -F 'p=<-' http://p.hashbang.ca
     http://p.hashbang.ca/f4s2
-    $ chromium-browser http://p.hashbang.ca/f4s2.#l7
+    $ chromium-browser http://p.hashbang.ca/f4s2+#l2
 
 =head1 DESCRIPTION
 
@@ -113,8 +117,9 @@ C<p> command to POST paste content. Your paste's ID is returned in the
 C<X-Pastebin-ID> header; the URL in the C<X-Pastebin-URL>, as well as the response
 content.
 
-Append a period to the URL to get line numbers. Add an anchor like C<#l1> to
-jump to the given line number, or click the line number you want.
+Append a plus sign to the URL to get line numbers. Add an anchor like C<#l1> to
+jump to the given line number, or click the line number you want. The line number
+for the selected line will be highlighted.
 
 =for test_synopsis 1;
 __END__
